.. curses-fzf documentation master file, created by
   sphinx-quickstart on Wed Mar  4 08:59:15 2026.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to curses-fzf's documentation!
======================================

.. toctree::
   :maxdepth: 2
   :caption: User Guide

   readme_link
   install
   basic_usage
   advanced_usage

.. toctree::
   :maxdepth: 2
   :caption: Api Reference

   FuzzyFinder
   scoring
   ScoringResult
   ColorTheme
   Exceptions
   genindex
